==> haskell-hls-eval-plugin-2.1.0.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-eval-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-eval-plugin-2.1.0.0-3evv9o5C2ia6O2kRAi9PjJ
key:                  hls-eval-plugin-2.1.0.0-3evv9o5C2ia6O2kRAi9PjJ
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  13c28a02847be1405026d4e0b9c25ed2
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.1.0.0-3evv9o5C2ia6O2kRAi9PjJ
depends:
    Diff-0.5-ISsha3r0HNr6M4FXs44tpp
    QuickCheck-2.15.0.1-KEw9aoMxM6q6i8cfYYug2V
    aeson-2.1.2.1-F8ZePgr6g4xL6kF4wsQx0x base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    extra-1.7.16-DH9VMRj2B4M59QQF4Jl9K7 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghcide-2.1.0.0-9wEdMJHA5Br1gmfl2Bel6F
    hashable-1.4.5.0-FUZ3820cmTgAr6H2g2EQN7
    hls-graph-2.1.0.0-2QFOlIdOXB1EQzYhb7CYNU
    hls-plugin-api-2.1.0.0-5s4wGiPE7ZyAjQx1zm0Avf
    lens-5.3.1-FP95Rv35No71PYJue58Hxp
    lsp-2.1.0.0-18Q2QtPoX9S3SH5LibVquJ
    lsp-types-2.0.1.0-1eMLdOZCbkW9W9lcuT572q
    megaparsec-9.7.0-7jzSygYb9UCHSxVBa30IvK mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    pretty-simple-4.1.3.0-5lf1cQ3H4drE0DLfrcpuJ3
    safe-exceptions-0.1.7.4-DatoBNNbUvrEZ4aGgsucI4 text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-JFZIPKypuxSaOakmu5k8d
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-eval-plugin-2.1.0.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-eval-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-eval-plugin-2.1.0.0-EPNtxG5zr6k8CRTx4bKu8n
key:                  hls-eval-plugin-2.1.0.0-EPNtxG5zr6k8CRTx4bKu8n
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f633d4e45ea36cea68f92768379e29fc
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.1.0.0-EPNtxG5zr6k8CRTx4bKu8n
depends:
    Diff-0.5-2WBqMHHuMKKJPXXpUwfTmb
    QuickCheck-2.15.0.1-7dsjbuPrJB87A5nQdB1dNE
    aeson-2.1.2.1-IZ8jLcnEISD7S5Vyf2Tehm base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    extra-1.7.16-84Gt3POgtfP5cuz093nHzi filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghcide-2.1.0.0-5uvZBkxV56sGavtIKVzKoa
    hashable-1.4.5.0-FhpNKvHQsJeLXuGJFx8piW
    hls-graph-2.1.0.0-DAPyPd75bi7IFSKW1TrIIy
    hls-plugin-api-2.1.0.0-A59IlVXfXQg7mPrDkck9GR
    lens-5.3.1-K6M28KdwyDFInfMmFpBOSR
    lsp-2.1.0.0-GqUkT7LWD5z2j8vkLZwoGo
    lsp-types-2.0.1.0-FG5BWlrUV2lI4l6HCIYHLz
    megaparsec-9.7.0-EujlCtvd6hmm53pqN4SFa mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    pretty-simple-4.1.3.0-5b0snePE1mm42Z9rumxIIV
    safe-exceptions-0.1.7.4-I4XEAJHEDzt7DtP882KCHj text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-FyGtu4mqD7wCBxP02zQmU8
    unordered-containers-0.2.20-79maJZZuZDu8bRI1CHuoJG

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
